# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-01-18 08:01
from __future__ import unicode_literals

import collectd_rest.models
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('collectd_rest', '0003_graphgranularity'),
    ]

    operations = [
        migrations.AlterField(
            model_name='graph',
            name='granularity',
            field=models.ForeignKey(default=collectd_rest.models.default_graph_granularity, on_delete=django.db.models.deletion.PROTECT, related_name='graphs', to='collectd_rest.GraphGranularity'),
        ),
    ]



try:
	from django.urls import reverse
except ImportError:
	from django.core.urlresolvers import reverse
from django.test import TestCase
from rest_framework import status
from rest_framework.test import APIClient
from collectd_rest.models import GraphGranularity, GraphGroup, Graph

class GraphGranularityTest(TestCase):
	def setUp(self):
		self.client = APIClient()

	def test_granularity_create1(self):
		url = reverse('graphgranularity-list')
		response = self.client.post(url, {
			'name': 'custom',
			'max_age': 42}, format='json')
		self.assertEqual(response.status_code, status.HTTP_201_CREATED)
		granularity = GraphGranularity.objects.get(name="custom")
		self.assertEqual(granularity.max_age, 42)
	def test_granularity_create2(self):
		url = reverse('graphgranularity-list')
		# name is missed here
		response = self.client.post(url, {
			'max_age': 42}, format='json')
		# max_age is missed here
		response = self.client.post(url, {
			'name': 'custom'}, format='json')
		self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
	def test_granularity_create3(self):
		url = reverse('graphgranularity-list')
		# default is always exists
		response = self.client.post(url, {
			'name': 'default',
			'max_age': 42}, format='json')
		self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)



# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-01-18 02:42
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('collectd_rest', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='graph',
            name='name',
            field=models.SlugField(max_length=256),
        ),
        migrations.AlterField(
            model_name='graphgroup',
            name='name',
            field=models.SlugField(max_length=256, unique=True),
        ),
    ]



from collectd_rest.rrd import render
from django.db import models

class GraphGranularity(models.Model):
	name = models.SlugField(max_length=256, blank = False, unique = True)
	max_age = models.PositiveIntegerField(blank = False)

	def __repr__(self):
		return '<GraphGranularity %s>' % self.name

class GraphGroup(models.Model):
	name = models.SlugField(max_length=256, blank = False, unique = True)
	title = models.CharField(max_length=256, blank = False)

	def __repr__(self):
		return '<GraphGroup %s>' % self.name

# lambdas can't be used for field options like default because they can't be
# serialized by migrations.
def default_graph_granularity():
	return GraphGranularity.objects.get(name='default').pk

class Graph(models.Model):
	name = models.SlugField(max_length=256, blank = False)
	title = models.CharField(max_length=256, blank = True)
	priority = models.IntegerField(default=0)
	group = models.ForeignKey('GraphGroup', on_delete=models.CASCADE, related_name='graphs')
	command = models.TextField(blank = False)
	granularity = models.ForeignKey('GraphGranularity', on_delete=models.PROTECT, default=default_graph_granularity, related_name='graphs')

	class Meta:
		unique_together = ("name", "group")
		ordering = ['-priority']

	def render(self, format):
		return render(self.command, format)

	def __repr__(self):
		return '<Graph %s in %s>' % (self.name, self.group.name)



from tests.graph import GraphTest
from tests.granularity import GraphGranularityTest
from tests.group import GraphGroupTest
from tests.rrd import RRDTest

__all__ = ['GraphTest', 'GraphGranularityTest', 'GraphGroupTest', 'RRDTest']



from collectd_rest import models, serializers, renderers
from rest_framework import viewsets
from rest_framework.settings import api_settings

class GraphGranularityViewSet(viewsets.ModelViewSet):
	queryset = models.GraphGranularity.objects.all()
	serializer_class = serializers.GraphGranularitySerializer
	lookup_field = 'name'

class GraphGroupViewSet(viewsets.ModelViewSet):
	queryset = models.GraphGroup.objects.all()
	serializer_class = serializers.GraphGroupSerializer
	lookup_field = 'name'

class GraphViewSet(viewsets.ModelViewSet):
	queryset = models.Graph.objects.prefetch_related('granularity').all()
	serializer_class = serializers.GraphSerializer
	renderer_classes = api_settings.DEFAULT_RENDERER_CLASSES + [renderers.PNGRenderer, renderers.SVGRenderer, ]
